@@ -183,6 +183,11 @@ class Refactor:
             analyzer = scan.SourceAnalyzer(original_lines)
             analyzer.visit(tree)
             source_stats, import_stats = analyzer.get_stats()
+
+            if regexu.is_init_file(self._path) and not analyzer.has_all():
+                self.reporter.init_without_all_warning(self._path)
+                return None
+
             return source_stats, import_stats
         except Exception as err:
             self.reporter.failure(str(err), self._path)
@@ -227,7 +232,7 @@ class Refactor:
                         self.reporter.removed_import(self._path, node, star_alias)
 
                 # No alias has removed/added.
-                if len(used_names) == len(node.names):
+                if used_names and len(used_names) == len(node.names):
                     if not self.configs.expand_stars:
                         continue
 
